@@ -26,10 +26,7 @@ class BaseConfig:
     def dump(self) -> None:
         with open(BASE_CONFIG_FILE, "w") as fp:
             d = asdict(self)
-            d = {
-                k: v if not isinstance(v, Path) else str(v)
-                for k, v in d.items()
-            }
+            d = {k: v if not isinstance(v, Path) else str(v) for k, v in d.items()}
             json.dump(d, fp, indent=2)
 
     @classmethod
@@ -68,10 +65,7 @@ class Config:
     def dump(self) -> None:
         with open(self.config_file, "w") as fp:
             d = asdict(self)
-            d = {
-                k: v if not isinstance(v, Path) else str(v)
-                for k, v in d.items()
-            }
+            d = {k: v if not isinstance(v, Path) else str(v) for k, v in d.items()}
             json.dump(d, fp, indent=2)
 
     def reset(self) -> None:
@@ -154,9 +148,7 @@ logging.config.dictConfig(
         "version": 1,
         "disable_existing_loggers": True,
         "formatters": {
-            "standard": {
-                "format": "%(asctime)s [%(levelname)s] %(name)s: %(message)s"
-            },
+            "standard": {"format": "%(asctime)s [%(levelname)s] %(name)s: %(message)s"},
         },
         "handlers": {
             "file": {
